;; Generated package description from hiddenquote.el  -*- no-byte-compile: t -*-
(define-package "hiddenquote" "1.2.0.20231107.184113" "Major mode for doing hidden quote puzzles" '((emacs "25.1")) :commit "c0677533e8aa6b2734e7b4b6f0b977a5c226acff" :authors '(("Mauro Aranda" . "maurooaranda@gmail.com")) :maintainer '("Mauro Aranda" . "maurooaranda@gmail.com") :keywords '("games") :url "http://mauroaranda.com/puzzles/hidden-quote-puzzle/")
